# nitrogen

NITROGEN is a Python package for nuclear motion calculations and ab initio rovibronic spectroscopy of small molecules.

It is available from PyPI via `pip install nitrogen`. The source repository is [here](https://github.com/bchangala/nitrogen).

Documentation is available on [Read the Docs](https://nitrogen-docs.readthedocs.io).

NITROGEN ver. 2.x is a complete re-write in Python, currently in initial development and planning. The original C code (ver. 1.x) is available [here](https://www.colorado.edu/nitrogen).
